@@ -1,27 +1,8 @@
 /* ============================================================
 *
-* This file is part of the KDE project
+* SPDX-FileCopyrightText: 2008 Kare Sars <kare dot sars at iki dot fi>
 *
-* Date        : 2008-11-15
-* Description : Preview image viewer that can handle a selection.
-*
-* Copyright (C) 2008 by Kare Sars <kare dot sars at iki dot fi>
-*
-* This library is free software; you can redistribute it and/or
-* modify it under the terms of the GNU Lesser General Public
-* License as published by the Free Software Foundation; either
-* version 2.1 of the License, or (at your option) version 3, or any
-* later version accepted by the membership of KDE e.V. (or its
-* successor approved by the membership of KDE e.V.), which shall
-* act as a proxy defined in Section 6 of version 3 of the license.
-*
-* This library is distributed in the hope that it will be useful,
-* but WITHOUT ANY WARRANTY; without even the implied warranty of
-* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-* Lesser General Public License for more details.
-*
-* You should have received a copy of the GNU Lesser General Public
-* License along with this program.  If not, see <http://www.gnu.org/licenses/>.
+* SPDX-License-Identifier: LGPL-2.1-only OR LGPL-3.0-only OR LicenseRef-KDE-Accepted-LGPL
 *
 * ============================================================ */
 
@@ -34,12 +15,15 @@
 namespace KSaneIface
 {
 
+/*
+ * Preview image viewer that can handle a selection.
+ */
 class KSaneViewer : public QGraphicsView
 {
     Q_OBJECT
 public:
     explicit KSaneViewer(QImage *img, QWidget *parent = nullptr);
-    ~KSaneViewer();
+    ~KSaneViewer() override;
 
     void setQImage(QImage *img);
     void updateImage();
@@ -49,6 +33,9 @@ public:
 
     QSize sizeHint() const override;
 
+    int currentImageHeight() const;
+    int currentImageWidth() const;
+
 public Q_SLOTS:
 
     void setTLX(float ratio);
